@@ -70,7 +70,7 @@ save_info(GtkWidget *wid, gpointer user_data)
 		lst = NULL;
 	}
 	
-        gtk_main_quit();
+	gtk_widget_set_sensitive ( GTK_WIDGET(confirm), FALSE );
 
 }
 
@@ -165,6 +165,7 @@ set_shortcut ( HildonTouchSelector * selector, gint column, gpointer user_data )
 							icons[pos] = ico;
 							ossos[pos] = oss;
 							bins[pos] = bin;
+							gtk_widget_set_sensitive ( GTK_WIDGET(confirm), TRUE );
 		                        	}
 					}
 				}
@@ -232,7 +233,6 @@ osso_return_t execute(osso_context_t *osso, gpointer data, gboolean user_activat
 	GtkWidget	*action_box;
 
 	GtkWidget	*sel1,*sel2,*sel3,*sel4;
-	GtkWidget 	*confirm,*cancel;
 	GConfClient	*client;
 
 
@@ -283,13 +283,9 @@ osso_return_t execute(osso_context_t *osso, gpointer data, gboolean user_activat
 
 	confirm = hildon_button_new(HILDON_SIZE_AUTO, HILDON_BUTTON_ARRANGEMENT_VERTICAL);
 	hildon_button_set_text ( HILDON_BUTTON(confirm), "Ok", NULL );
-	hildon_button_set_image ( HILDON_BUTTON(confirm), gtk_image_new_from_stock(GTK_STOCK_OK, GTK_ICON_SIZE_BUTTON) );
-	cancel = hildon_button_new(HILDON_SIZE_AUTO, HILDON_BUTTON_ARRANGEMENT_VERTICAL);
-	hildon_button_set_text ( HILDON_BUTTON(cancel), "Cancel", NULL);
-	hildon_button_set_image ( HILDON_BUTTON(cancel), gtk_image_new_from_stock(GTK_STOCK_CANCEL, GTK_ICON_SIZE_BUTTON) );
-
+	hildon_button_set_image ( HILDON_BUTTON(confirm), gtk_image_new_from_stock(GTK_STOCK_APPLY, GTK_ICON_SIZE_BUTTON) );
+	
 	gtk_box_pack_start ( GTK_BOX(action_box), confirm, FALSE,FALSE,0 );
-	gtk_box_pack_start ( GTK_BOX(action_box), cancel, FALSE,FALSE,0 );
 
 	gtk_box_pack_start ( GTK_BOX(main_box), conf_box, TRUE, TRUE, 1 );
 	gtk_box_pack_start ( GTK_BOX(main_box), action_box, TRUE, FALSE, 1 );
@@ -306,7 +302,8 @@ osso_return_t execute(osso_context_t *osso, gpointer data, gboolean user_activat
 	g_signal_connect ( G_OBJECT(sel3), "changed", G_CALLBACK(set_shortcut), (gpointer)2 );
 	g_signal_connect ( G_OBJECT(sel4), "changed", G_CALLBACK(set_shortcut), (gpointer)3 );
 	g_signal_connect ( G_OBJECT(confirm), "clicked", G_CALLBACK(save_info), client );
-	g_signal_connect ( G_OBJECT(cancel), "clicked", G_CALLBACK(gtk_main_quit), NULL );
+	
+	gtk_widget_set_sensitive ( GTK_WIDGET(confirm), FALSE );
 	
 	gtk_widget_show_all ( GTK_WIDGET(window) );
 	
